@@ -1,10 +1,11 @@
 // Copyright Contributors to the OpenImageIO project.
 // SPDX-License-Identifier: Apache-2.0
-// https://github.com/OpenImageIO/oiio
+// https://github.com/AcademySoftwareFoundation/OpenImageIO
 
 #pragma once
 #define OIIO_FMT_H
 
+#include <OpenImageIO/dassert.h>
 #include <OpenImageIO/platform.h>
 #include <OpenImageIO/type_traits.h>
 
@@ -18,6 +19,16 @@
 #    define FMT_EXCEPTIONS 0
 #endif
 
+#if OIIO_VERSION_LESS(3, 1, 2)
+/* DEPRECATED -- remove at next ABI compatibility boundary */
+OIIO_NAMESPACE_BEGIN
+namespace pvt {
+OIIO_UTIL_API void
+log_fmt_error(const char* message);
+};
+OIIO_NAMESPACE_END
+#endif
+
 // Use the grisu fast floating point formatting for old fmt versions
 // (irrelevant for >= 7.1).
 #ifndef FMT_USE_GRISU
@@ -38,13 +49,20 @@
 #    define FMT_USE_FLOAT128 0
 #endif
 
+// Suppress certain warnings generated in the fmt headers themselves
 OIIO_PRAGMA_WARNING_PUSH
 #if OIIO_GNUC_VERSION >= 70000
 #    pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
 #endif
+#if OIIO_GNUC_VERSION >= 130000
+#    pragma GCC diagnostic ignored "-Wdangling-reference"
+#endif
 #if OIIO_INTEL_LLVM_COMPILER
 #    pragma GCC diagnostic ignored "-Wtautological-constant-compare"
 #endif
+#if OIIO_CLANG_VERSION >= 180000
+#    pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#endif
 
 #include <OpenImageIO/detail/fmt/format.h>
 #include <OpenImageIO/detail/fmt/ostream.h>
@@ -52,6 +70,13 @@ OIIO_PRAGMA_WARNING_PUSH
 
 OIIO_PRAGMA_WARNING_POP
 
+// At some point a method signature changed
+#if FMT_VERSION >= 90000
+#    define OIIO_FMT_CUSTOM_FORMATTER_CONST const
+#else
+#    define OIIO_FMT_CUSTOM_FORMATTER_CONST
+#endif
+
 
 OIIO_NAMESPACE_BEGIN
 namespace pvt {
@@ -106,7 +131,8 @@ template<typename T,
          OIIO_ENABLE_IF(has_subscript<T>::value&& has_size_method<T>::value)>
 struct index_formatter : format_parser_with_separator {
     // inherits parse() from format_parser_with_separator
-    template<typename FormatContext> auto format(const T& v, FormatContext& ctx)
+    template<typename FormatContext>
+    auto format(const T& v, FormatContext& ctx) OIIO_FMT_CUSTOM_FORMATTER_CONST
     {
         std::string vspec = elem_fmt.size() ? fmt::format("{{:{}}}", elem_fmt)
                                             : std::string("{}");
@@ -128,7 +154,7 @@ struct index_formatter : format_parser_with_separator {
 // fmtlib custom formatter that formats a type `T` as if it were an array
 // `Elem[Size]` (and it must be laid out that way in memory). The formatting
 // spec will apply to each element. For example, if the object has 3 float
-// elements and the spec is "{.3f}", then the output might be "1.234 2.345
+// elements and the spec is "{:.3f}", then the output might be "1.234 2.345
 // 3.456".
 //
 // In addition to the usual formatting spec, we also recognize the following
@@ -150,7 +176,8 @@ struct index_formatter : format_parser_with_separator {
 template<typename T, typename Elem, int Size>
 struct array_formatter : format_parser_with_separator {
     // inherits parse() from format_parser_with_separator
-    template<typename FormatContext> auto format(const T& v, FormatContext& ctx)
+    template<typename FormatContext>
+    auto format(const T& v, FormatContext& ctx) OIIO_FMT_CUSTOM_FORMATTER_CONST
     {
         std::string vspec = elem_fmt.size() ? fmt::format("{{:{}}}", elem_fmt)
                                             : std::string("{}");
