@@ -184,10 +184,7 @@ public:
     }
 
     /// Copy construct a ustring from another ustring.
-    ustring(const ustring& str) noexcept
-        : m_chars(str.m_chars)
-    {
-    }
+    ustring(const ustring& str) noexcept = default;
 
     /// Construct a ustring from an indexed substring of a ustring.
     ustring(const ustring& str, size_type pos, size_type n = npos)
@@ -203,7 +200,7 @@ public:
 #endif
 
     /// ustring destructor.
-    ~ustring() noexcept {}
+    ~ustring() noexcept = default;
 
     /// Conversion to an OIIO::string_view.
     operator string_view() const noexcept { return { c_str(), length() }; }
@@ -212,79 +209,75 @@ public:
     explicit operator std::string() const noexcept { return string(); }
 
     /// Assign a ustring to *this.
-    const ustring& assign(const ustring& str)
+    ustring& assign(const ustring& str)
     {
         m_chars = str.m_chars;
         return *this;
     }
 
     /// Assign a substring of a ustring to *this.
-    const ustring& assign(const ustring& str, size_type pos, size_type n = npos)
+    ustring& assign(const ustring& str, size_type pos, size_type n = npos)
     {
         *this = ustring(str, pos, n);
         return *this;
     }
 
     /// Assign a std::string to *this.
-    const ustring& assign(const std::string& str)
+    ustring& assign(const std::string& str)
     {
         assign(str.c_str());
         return *this;
     }
 
     /// Assign a substring of a std::string to *this.
-    const ustring& assign(const std::string& str, size_type pos,
-                          size_type n = npos)
+    ustring& assign(const std::string& str, size_type pos, size_type n = npos)
     {
         *this = ustring(str, pos, n);
         return *this;
     }
 
     /// Assign a null-terminated C string (char*) to *this.
-    const ustring& assign(const char* str)
+    ustring& assign(const char* str)
     {
         m_chars = str ? make_unique(str) : nullptr;
         return *this;
     }
 
     /// Assign the first n characters of str to *this.
-    const ustring& assign(const char* str, size_type n)
+    ustring& assign(const char* str, size_type n)
     {
         *this = ustring(str, n);
         return *this;
     }
 
     /// Assign n copies of c to *this.
-    const ustring& assign(size_type n, char c)
+    ustring& assign(size_type n, char c)
     {
         *this = ustring(n, c);
         return *this;
     }
 
     /// Assign a string_view to *this.
-    const ustring& assign(string_view str)
+    ustring& assign(string_view str)
     {
         m_chars = str.length() ? make_unique(str) : nullptr;
         return *this;
     }
 
     /// Assign a ustring to another ustring.
-    const ustring& operator=(const ustring& str) { return assign(str); }
+    ustring& operator=(const ustring& str) noexcept = default;
 
     /// Assign a null-terminated C string (char *) to a ustring.
-    const ustring& operator=(const char* str) { return assign(str); }
+    ustring& operator=(const char* str) { return assign(str); }
 
     /// Assign a C++ std::string to a ustring.
-    const ustring& operator=(const std::string& str) { return assign(str); }
+    ustring& operator=(const std::string& str) { return assign(str); }
 
     /// Assign a string_view to a ustring.
-    const ustring& operator=(string_view str) { return assign(str); }
+    ustring& operator=(string_view str) { return assign(str); }
 
     /// Assign a single char to a ustring.
-    const ustring& operator=(char c)
-    {
-        return *this = ustring(string_view(&c, 1));
-    }
+    ustring& operator=(char c) { return *this = ustring(string_view(&c, 1)); }
 
     /// Return a C string representation of a ustring.
     const char* c_str() const noexcept { return m_chars; }
@@ -676,16 +669,6 @@ public:
         return ustring(Strutil::fmt::format(fmt, args...));
     }
 
-    /// NOTE: Semi-DEPRECATED! This will someday switch to behave like
-    /// fmt::format (or future std::format) but for now, it is back
-    /// compatible and equivalent to sprintf.
-    template<typename... Args>
-    OIIO_FORMAT_DEPRECATED static ustring format(const char* fmt,
-                                                 const Args&... args)
-    {
-        return ustring(Strutil::format(fmt, args...));
-    }
-
     /// Concatenate two strings, returning a ustring, implemented carefully
     /// to not perform any redundant copies or allocations.
     static ustring concat(string_view s, string_view t);
@@ -803,10 +786,10 @@ public:
     ~ustringhash() noexcept = default;
 
     /// Copy construct a ustringhash from another ustringhash.
-    OIIO_HOSTDEVICE constexpr ustringhash(const ustringhash& str) noexcept
-        : m_hash(str.m_hash)
-    {
-    }
+    constexpr ustringhash(const ustringhash& str) noexcept = default;
+
+    /// Move construct a ustringhash from another ustringhash.
+    ustringhash(ustringhash&& str) noexcept = default;
 
     /// Construct from a ustring
     ustringhash(const ustring& str) noexcept
@@ -870,15 +853,11 @@ public:
     }
 
     /// Assign from a ustringhash
-    OIIO_HOSTDEVICE constexpr const ustringhash&
-    operator=(const ustringhash& str)
-    {
-        m_hash = str.m_hash;
-        return *this;
-    }
+    constexpr ustringhash& operator=(const ustringhash& str) = default;
+    ustringhash& operator=(ustringhash&& str)                = default;
 
     /// Assign from a ustring
-    const ustringhash& operator=(const ustring& str)
+    ustringhash& operator=(const ustring& str)
     {
         m_hash = str.hash();
         return *this;
@@ -940,13 +919,13 @@ public:
     }
 
     /// Test for equality with a char*.
-    OIIO_CONSTEXPR17 bool operator==(const char* str) const noexcept
+    constexpr bool operator==(const char* str) const noexcept
     {
         return m_hash == Strutil::strhash(str);
     }
 
     /// Test for inequality with a char*.
-    OIIO_CONSTEXPR17 bool operator!=(const char* str) const noexcept
+    constexpr bool operator!=(const char* str) const noexcept
     {
         return m_hash != Strutil::strhash(str);
     }
@@ -1032,30 +1011,22 @@ inline ustring::ustring(ustringhash hash)
 
 
 /// ustring string literal operator
-inline ustring operator""_us(const char* str, std::size_t len)
+inline ustring
+operator""_us(const char* str, std::size_t len)
 {
     return ustring(str, len);
 }
 
 
 /// ustringhash string literal operator
-OIIO_DEVICE_CONSTEXPR ustringhash operator""_ush(const char* str,
-                                                 std::size_t len)
+OIIO_DEVICE_CONSTEXPR ustringhash
+operator""_ush(const char* str, std::size_t len)
 {
     return ustringhash(str, len);
 }
 
 
 
-#if OIIO_VERSION_LESS(3, 0, 0)
-/// Deprecated -- This is too easy to confuse with the ustringhash class. And
-/// also it is unnecessary if you use std::hash<ustring>. This will be removed
-/// in OIIO 3.0.
-using ustringHash = std::hash<ustring>;
-#endif
-
-
-
 /// Functor class to use for comparisons when sorting ustrings, if you
 /// want the strings sorted lexicographically.
 class ustringLess {
@@ -1160,8 +1131,8 @@ FMT_BEGIN_NAMESPACE
 
 template<> struct formatter<OIIO::ustring> : formatter<fmt::string_view, char> {
     template<typename FormatContext>
-    auto format(const OIIO::ustring& u, FormatContext& ctx)
-        -> decltype(ctx.out()) const
+    auto format(const OIIO::ustring& u,
+                FormatContext& ctx) OIIO_FMT_CUSTOM_FORMATTER_CONST
     {
         return formatter<fmt::string_view, char>::format({ u.data(), u.size() },
                                                          ctx);
@@ -1171,8 +1142,8 @@ template<> struct formatter<OIIO::ustring> : formatter<fmt::string_view, char> {
 template<>
 struct formatter<OIIO::ustringhash> : formatter<fmt::string_view, char> {
     template<typename FormatContext>
-    auto format(const OIIO::ustringhash& h, FormatContext& ctx)
-        -> decltype(ctx.out()) const
+    auto format(const OIIO::ustringhash& h,
+                FormatContext& ctx) OIIO_FMT_CUSTOM_FORMATTER_CONST
     {
         OIIO::ustring u(h);
         return formatter<fmt::string_view, char>::format({ u.data(), u.size() },
